summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/kcategoryreassigndlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/kcategoryreassigndlg.h')
-rw-r--r--kmymoney2/dialogs/kcategoryreassigndlg.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kmymoney2/dialogs/kcategoryreassigndlg.h b/kmymoney2/dialogs/kcategoryreassigndlg.h
index ce756ee..4639bd4 100644
--- a/kmymoney2/dialogs/kcategoryreassigndlg.h
+++ b/kmymoney2/dialogs/kcategoryreassigndlg.h
@@ -21,7 +21,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -39,9 +39,10 @@
class KCategoryReassignDlg : public KCategoryReassignDlgDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Default constructor */
- KCategoryReassignDlg( QWidget* parent = 0, const char* name = 0);
+ KCategoryReassignDlg( TQWidget* tqparent = 0, const char* name = 0);
/** Destructor */
~KCategoryReassignDlg();
@@ -52,11 +53,11 @@ public:
*
* @param category reference to MyMoneyAccount object of the category to be deleted
*
* @return Returns the id of the selected category in the list or QString() if
* the dialog was aborted. QString() is also returned if the @a category
* does not have an id.
*/
- QString show(const MyMoneyAccount& category);
+ TQString show(const MyMoneyAccount& category);
protected:
void accept(void);
@@ -52,11 +53,11 @@ public:
* @param category reference to MyMoneyAccount object of the category to be deleted
*
- * @return Returns the id of the selected category in the list or QString() if
- * the dialog was aborted. QString() is also returned if the @a category
+ * @return Returns the id of the selected category in the list or TQString() if
+ * the dialog was aborted. TQString() is also returned if the @a category
* does not have an id.
*/